# Wie führe ich eine gute Wettbewerbsanalyse für Keywords durch 😊

> **Source:** [Antonio Blago](https://www.youtube.com/channel/UCoIBDdswc5VViHYPTKd0HwA) | **Duration:** 05:45 | **Published:** 20260224
> **URL:** [https://www.youtube.com/watch?v=OzJdYOxVGuw](https://www.youtube.com/watch?v=OzJdYOxVGuw)
> **Views:** 20 | **Likes:** 1

In diesem Video erkläre ich, wie man eine effektive Wettbewerbsanalyse für Keywords durchführt. Ich zeige anhand eines Beispiels, wie man die Top-Konkurrenten identifiziert, ihren Traffic analysiert und ihre Backlinks überprüft. Außerdem gebe ich Tipps zur Verteilung des organischen Rankings. Schau ...

---

## Table of Contents

- [Segment 1](#segment-1-00:00-02:00)
- [Segment 2](#segment-2-02:00-04:00)
- [Segment 3](#segment-3-04:00-05:45)

---

### Segment (00:00 - 02:00)

wie F euch jetzt eine gute Wettbewerbsanalyse für die Keywords durch und da kannst du das Feature von SE Ranking auch nutzen Wettbewerbsanalyse und zwar gehe ich immer so vor wenn ich ein neues Projekt starte das Keyword wofür mein Kunde Ranken will oder ich Ranken will suche ich als erstes z.B Personal Training Köln und dann also das ist quasi das Ziel Keyword und dann suche ich z.B okay wer sind die Top 3 Top 5 ne und dann sehe ich z.B hier mrköln.de Toplisten den Link öffne ich den Link öffne ich den Link öffne ich genau und dann schaue ich mir hier die Seiten an also es ist quasi einfach ein Beispiel hier und die sind auf jeden Fall die bestgelistetesten in die Suche für Köln und dann kopiere ich mir diese URL und kopiere sie hier rein lass se Ranking mir diese URL alysieren und dann sehe ich schon gleich okay die Domain mrköln.de die hat elich ganz guten Traffic schon mal also 70 000 Klicks pro Monat insgesamt sind sie schon für 22000 Keywords gerankt mit dem absteigenden Trend und dann sind die trafficosten auch bei 20000 das heißt Gegenwert also Traffic auf Google

---

### Segment (02:00 - 04:00)

auch bei 20000 das heißt Gegenwert also Traffic auf Google Ads zu generieren bräuchtest du 20.000 € im Monat und da sieht man schon auch die Power hinter organisch organisches Ranking dann sieht man auch bei Ranking auch immer hier dieses diesen verlaufsdiagramm also für den Traffic insgesamt grün ist jeweils organisch und blaues bezahlt hier haben sie quasi nur organischen Traffic und dann kann man auch sehen über 18 Monate und den ganzen Zeitrum hinweg und da sieht man auf jeden Fall die haben ja ansteigigenen Traffic also tun sie auf jeden Fall schon mal was denke ich mal und hier sieht man auch die ansteigenden Keywords muss halt sagen nur weil du mehr Content und Keywords generierst muss auch nicht gleich gleichzeitig den Traffic hier so hochgen das ist meistens leider nicht so hier ist es der Fall aber gut für Sie genau da hat man hier noch trafficosten und Backlinks auch immer ganz guter Hinweis also welche Seiten werden wie quasi von den verlinkt da da ma ich noch mal ein separates Video dazu wie du das ganze auswertest mit eranking n mal so als Hinweis dann hier siehst du dann die verweisenden Domains also unterschiedliche Domains und dann die Anzahl aller Backlinks also eine Domain kann auch mehrere Backlinks haben die auf deine Seite verweist genau und dann siehst du hier noch ein gutes Feature das heißt diese Keywords Liste das kannst du hier auch aufmachen

---

### Segment (04:00 - 05:45)

Keywords Liste das kannst du hier auch aufmachen und dann siehst Du diese ganzen Keywords für die deine Konkurrenz quasi dann rankt ne und dann kannst du die diese auch hier in deiner Keyword Recherche beispielsweise auch exportieren lassen und dann auch mit deinen keywordlisten zusammenfügen genau und was auch immer sehr wichtig ist in der Konkurrenzanalyse ist dann auch die Verteilung des organischen Rankings also die Verteilung der Keywords anhand der der der Rankings also Top 1 bis 5 Plätze 6 bis 10 11 bis 20 21 bis 50 und 51 bis 100 also das sind quasi so Kategorien ne und man möchte eigentlich eher natürlich hier die meisten Keywords haben aber das ist meistens nicht möglich insofern wird immer nur ein Teil eurer ganzen Keywords hier unten gerankt werden in den toppatzierung am guutter Richtwert ist auf jeden Fall mindestens 5% aller deiner Keywords hier zu ranken auf den Top 1 bis 5 Plätzen und hier auch noch mal mehr als 5% zu ranken und hier ähm so wenig wie mögliche dann ähm zu haben ne genau das war's jetzt erstmal und ich werde noch im weiteren Video alle möglichen einzelheiten dazu erklären

---


*Transcript source: youtube_auto_generated*
*Confidence: 80%*